@@ -171,7 +171,7 @@ $index must be less than the length of $list. Otherwise an exception is thrown.
 
 C<method replace : void ($index : int, $remove_length : int, $replace : string[]);>
 
-Replaces the elements of the range specified by $index and $lenght with $replace array.
+Replaces the elements of the range specified by $index and $length with $replace array.
 
 Exceptions:
 
@@ -179,7 +179,7 @@ $index must be greater than or equal to 0. Otherwise an exception is thrown.
 
 $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-$index + $removing lenght must be less than or equal to the length of $list. Otherwise an exception is thrown.
+$index + $removing length must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 reserve
 
@@ -209,7 +209,7 @@ $offset must be greater than or equal to 0. Otherwise an exception is thrown.
 
 $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-$offset + $removing lenght must be less than or equal to the length of $list. Otherwise an exception is thrown.
+$offset + $removing length must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 set
 
